@@ -1,9 +1,13 @@
+# -*- coding: utf-8 -*-
+
 from .react import React, set_up
 from . import utils
+from . import excepts
 
 __all__ = [
     'set_up',
     'React',
-    'utils']
+    'utils',
+    'excepts']
 
-__version__ = '0.1.0'
+__version__ = '0.1.1'
